use vars qw(@ISA @EXPORT);
use Exporter;

@ISA = qw(Exporter);
@EXPORT = qw(usage scan_only select_service rand_ip);

sub usage {
  header();
  print "Usage: $0 [<options>] ...\n\n";
  print "Help: -s <ip|hostname>       - single destination host,\n"; 
  print "                               enter a ip address or a hostname\n";
  print "      -i <file>              - ip file\n";
  print "      -r                     - random destination host\n";
  print "      -l <count>             - loop count for random destination\n";
  print "                               scanning, default is 1\n";
  print "      -t <none|service|all>  - service to scan,\n";
  print "                               \"all\" to scan all services\n";
  print "                               or \"none\" to scan none service\n";
  print "                               or one service, look @ doc/SERVICES\n";
  print "      -h                     - show this help :)\n";
  print "      -c <file>              - to use another config file,\n";
  print "                               default is config/arb-scan.conf\n";
}

sub header {
  print "Arb-Scan(v$VERSION)\n";
  print "----------", ("-" x length($VERSION)), "-\n\n";
}

sub scan_only {
  my $dest = shift;
 
  system("scripts/./scan-nmap-all.sh", $dest, $SCANTYPE, $DONTPING);
}

sub scan_service {
  my ($dest, $service) = @_;
 
  my $line;

  system("scripts/./scan-nmap-service.sh", $dest, $service, $SCANTYPE, $DONTPING);
  open(FILE, "log/scan-$dest.log") || print "Can't open logfile(log/scan-$dest.log) because: $!\n"; 
  while($line = <FILE>) {
    if ($line =~ /\(0\shosts\sup\)/) {
      print "- host $dest wasn't scanned, reason unknown\n";
      exit(1);
    }
  }
}

sub rand_ip {
  my ($s1, $s2, $s3, $s4, $rand_ip);
  
  srand;
  $s1 = int(rand(255));
  $s2 = int(rand(255));
  $s3 = int(rand(255));
  $s4 = int(rand(255));
  $rand_ip = "$s1.$s2.$s3.$s4";
 
  return($rand_ip);
}   

sub check_all {
  my $dest = shift;

  scan_only($dest);
  check_time($dest);
  check_ftpd($dest);
  check_sshd($dest);
  check_smtp($dest);
  check_domain($dest);
  check_fingerd($dest);
  check_httpd($dest);
  check_pop2($dest);
  check_pop3($dest);
  check_nntp($dest);
  check_imap2($dest);
  check_imap3($dest);
  check_snpp($dest);
}

sub check_time {
  my $dest = shift;
  
  system("scripts/./check-time.sh", $dest);
}

sub check_domain {
  my $dest = shift;

  system("scripts/./check-domain.sh", $dest);
}

sub check_fingerd {
  my $dest = shift;

  system("scripts/./check-fingerd.sh", $dest);
}

sub check_httpd {
  my $dest = shift;

  system("scripts/./check-httpd.sh", $dest);
}

sub select_service {
  my ($dest, $service) = @_;

  if ($service =~ /daytime/i) {
    print "- start scan of $dest\n";
    scan_service($dest, 13);
    check_time($dest);
  }
  elsif ($service =~ /ftp/i) {
    print "- start scan of $dest\n";
    scan_service($dest, 21);
    check_ftpd($dest);
  }
  elsif ($service =~ /ssh/i) {
    print "- start scan of $dest\n";
    scan_service($dest, 22);
    check_sshd($dest);
  }
  elsif ($service =~ /smtp/i) {
    print "- start scan of $dest\n";
    scan_service($dest, 25);
    check_smtp($dest);
  }
  elsif ($service =~ /domain/i) {
    print "- start scan of $dest\n";
    scan_service($dest, 53);
    check_fingerd($dest);
  }
  elsif ($service =~ /finger/i) {
    print "- start scan of $dest\n";
    scan_service($dest, 79);
    check_fingerd($dest);
  }
  elsif ($service =~ /http/i) {
    print "- start scan of $dest\n";
    scan_service($dest, 80);
    check_httpd($dest);
  }
  elsif ($service =~ /pop2/i) {
    print "- start scan of $dest\n";
    scan_service($dest, 109);
    check_pop2($dest);
  }
  elsif ($service =~ /pop3/i) {
    print "- start scan of $dest\n";
    scan_service($dest, 110);
    check_pop3($dest);
  }
  elsif ($service =~ /nntp/i) {
    print "- start scan of $dest\n";
    scan_service($dest, 119);
    check_nntp($dest);
  }
  elsif ($service =~ /imap2/i) {
    print "- start scan of $dest\n";
    scan_service($dest, 143);
    check_imap2($dest);
  }
  elsif ($service =~ /imap3/i) {
    print "- start scan of $dest\n";
    scan_service($dest, 220);
    check_imap3($dest);
  }
  elsif ($service =~ /snpp/i) {
    print "- start scan of $dest\n";
    scan_service($dest, 444);
    check_snpp($dest);
  }
  elsif ($service =~ /none/i) {
    print "- start scan of $dest\n";
    scan_only($dest); 
  }
  elsif ($service =~ /all/i) {
    print "- start scan of $dest\n";
    check_all($dest);
  }
  else {
    usage();
  }
}

1;
